@@ -162,10 +162,11 @@ class AliyunOss(object):
             self.bucket.delete_object(exist_file_path)
         return True
 
-    def find_prefix_oss(self, ctx, oss_file_path, isrm=False):
+    def find_prefix_oss(self, ctx, oss_file_path, isrm=False, ftype='file'):
         """
         @des: 遍历oss文件夹，找到所有文件路径列表
         @params: isrm ------是否递归删除子目录下的文件
+                 ftype -----返回的文件类型 file--表示文件， folder--表示文件夹, all---表示文件和文件夹都返回
         """
         bucket = self.bucket
         oss_file_list = []
@@ -181,7 +182,13 @@ class AliyunOss(object):
         # 循环遍历即可
         for obj in file_iter:
             exist_file_path = obj.key
-            if not exist_file_path.endswith("/"):
+            if ftype == "file":
+                if not exist_file_path.endswith("/"):
+                    oss_file_list.append(exist_file_path)
+            elif ftype == "folder":
+                if exist_file_path.endswith("/"):
+                    oss_file_list.append(exist_file_path)
+            elif ftype == "all":
                 oss_file_list.append(exist_file_path)
         #
         return oss_file_list
