@@ -28,7 +28,7 @@ class SparkManage(object):
     """
 
     def __init__(self, ctx, code_path, is_async=False, is_log=False,
-                 s3_support=False, max_run_time=7200, task_params={},
+                 s3_support=False, tfrecord_support=False, max_run_time=7200, task_params={},
                  spark_config={'task_name': 'default',
                                'driver_cores': '1',
                                'driver_memory': '1G',
@@ -38,6 +38,7 @@ class SparkManage(object):
                                'image_url': 'registry-intl-vpc.us-east-1.aliyuncs.com/talefun/pyspark247:1.0'
                                },
                  is_debug=False,
+                 project_name='tt',
                  s3_params={}
                  ):
         """
@@ -62,11 +63,20 @@ class SparkManage(object):
         """
         self.ctx = ctx
         self.is_debug = is_debug  # 如果为true，就在mac本地调试
-        self.k8s_address = "https://47.253.49.211:6443"
-        self.oss_bucket = "pyspark-data"
+        self.project_name = project_name  # 切换本地调试集群
+         # tt->"https://47.253.49.211:6443"  tf->"https://47.90.134.59:6443"
+        if self.project_name == 'tf': 
+            self.k8s_address = "https://47.90.134.59:6443"
+        elif self.project_name == 'tt':
+            self.k8s_address = "https://47.253.49.211:6443"
+        # self.oss_bucket = "pyspark-data"
         if self.is_debug:  # mac本地测试环境
             self.spark_path = "/Users/yuanxiao/workspace/a_spark_study/spark-3.1.1-bin-hadoop2.7"
-            self.k8s_conn_config = "~/.kube/spark_config"
+            # tf--->config_split_tf  tt-->spark_config
+            if self.project_name == 'tf':
+                self.k8s_conn_config = "~/.kube/config_split_tf"
+            elif self.project_name == 'tt':
+                self.k8s_conn_config = "~/.kube/spark_config"
         else:  # 生产环境修改这个
             self.spark_path = "/mydata/spark-3.1.1-bin-hadoop2.7"
             self.k8s_conn_config = "~/.kube/config"
@@ -77,6 +87,7 @@ class SparkManage(object):
         self.is_log = is_log
         self.spark_config = spark_config
         self.s3_support = s3_support
+        self.tfrecord_support = tfrecord_support
         self.task_params = task_params  # 任务参数
         self.driver_pod_name = f"tfspark-{task_sub_name}-{self.max_run_time}-driver-{uuid.uuid1().hex}"
         self.oss_root_name = "oss_data"
@@ -85,9 +96,18 @@ class SparkManage(object):
         """
         # oss_config_file = "/opt/spark_oss.conf"
         if self.is_debug:  # mac本地测试环境
-            oss_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_oss.conf'
+            oss_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_oss_tf.conf'
+            # tf 和 tt后缀
+            if self.project_name == 'tf':
+                oss_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_oss_tf.conf'
+            elif self.project_name == 'tt':
+                oss_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_oss_tt.conf'
         else:
-            oss_config_file = '/opt/djcelery44/djcelery44/scripts/tools/spark_oss.conf'
+            if self.project_name=='tf':
+                oss_config_file = '/opt/djcelery44/djcelery44/scripts/tools/spark_oss_tf.conf'
+            elif self.project_name == 'tt':
+                oss_config_file = '/opt/djcelery44/djcelery44/scripts/tools/spark_oss_tt.conf'
+
         with open(oss_config_file, 'r') as f:
             oss_config = json.loads(f.read())
         self.oss_config = oss_config
@@ -96,18 +116,26 @@ class SparkManage(object):
         """
         # oss_config_file = "/opt/spark_oss.conf"
         if self.is_debug:  # mac本地测试环境
-            s3_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_s3.conf'
+            # tf 和 tt后缀
+            if self.project_name == 'tf':
+                s3_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_s3_tf.conf'
+            elif self.project_name == 'tt':
+                s3_config_file = '/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/spark_s3_tt.conf'
         else:
-            s3_config_file = '/opt/djcelery44/djcelery44/scripts/tools/spark_s3.conf'
+            if self.project_name=='tf':
+                s3_config_file = '/opt/djcelery44/djcelery44/scripts/tools/spark_s3_tf.conf'
+            elif self.project_name == 'tt':
+                s3_config_file = '/opt/djcelery44/djcelery44/scripts/tools/spark_s3_tt.conf'
         with open(s3_config_file, 'r') as f:
             s3_config = json.loads(f.read())
-        if s3_params: # 如果有传s3的配置，则用传入的s3配置
-            s3_config = s3_params # {"endpoint":"http://s3.us-west-2.amazonaws.com", "access_key":"", "secret_key":""}
+        if s3_params:  # 如果有传s3的配置，则用传入的s3配置
+            # {"endpoint":"http://s3.us-west-2.amazonaws.com", "access_key":"", "secret_key":""}
+            s3_config = s3_params
         self.s3_config = s3_config
         """
         生成k8s客户端
         """
-        self.k8s_client = K8sManage(ctx)
+        self.k8s_client = K8sManage(ctx, self.k8s_conn_config)
 
     def upload_code(self):
         """
@@ -126,7 +154,8 @@ class SparkManage(object):
         uoss.upload_oss(ctx, local_file_path, oss_file_path,
                         False, False, isrm=True, isdel=False)  # 递归查找, 不删除本地文件
         # uoss.download_oss(ctx, local_file_path+"xx", oss_file_path, isrm=True, isdel=False)  # 测试下载
-        self.real_code_path = os.path.join(f"/{self.oss_root_name}", oss_file_path)
+        self.real_code_path = os.path.join(
+            f"/{self.oss_root_name}", oss_file_path)
 
     def get_submit_spark_cmd(self):
         """
@@ -163,7 +192,7 @@ PYSPARK_DRIVER_PYTHON=/usr/bin/python3 \
 --conf spark.driver.memory={self.spark_config.get('driver_memory', '1G')} \
 --conf spark.executor.cores={self.spark_config.get('executor_cores', '1')} \
 --conf spark.executor.memory={self.spark_config.get('executor_memory', '1G')} \
-""" 
+"""
         # 重要点 第三方包的加入方法
         # 参考/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/debug/test_hello/main_depends_oss.py
         """
@@ -194,7 +223,7 @@ PYSPARK_DRIVER_PYTHON=/usr/bin/python3 \
         --conf spark.speculation=false \ 这句可以不加，加了影响性能
         ######
         """
-        
+
         s3_cmd = f"""--conf spark.hadoop.fs.s3a.endpoint={self.s3_config['endpoint']} \
 --conf spark.hadoop.fs.s3a.connection.ssl.enabled=false \
 --conf spark.hadoop.fs.s3a.access.key={self.s3_config['access_key']} \
@@ -210,6 +239,11 @@ PYSPARK_DRIVER_PYTHON=/usr/bin/python3 \
 --conf "spark.driver.extraJavaOptions=-Dcom.amazonaws.services.s3.enableV4=true" \
 --conf spark.hadoop.mapreduce.fileoutputcommitter.algorithm.version=2 \
     """
+        """
+        tfrecord的支持
+        """
+        tfrecord_cmd = f"""--conf spark.jars=local:///{self.oss_root_name}/python_dependencies/sparkjars/spark-tensorflow-connector_2.11-1.15.0.jar \
+"""
         """
         # 执行代码配置---执行main.py文件
         """
@@ -222,8 +256,9 @@ PYSPARK_DRIVER_PYTHON=/usr/bin/python3 \
         """
         拼接命令
         """
-        submit_cmd = base_cmd+volum_cmd + \
-            (s3_cmd if self.s3_support else "") + code_cmd
+        submit_cmd = base_cmd+volum_cmd + (s3_cmd if self.s3_support else "") + (
+            tfrecord_cmd if self.tfrecord_support else "") + code_cmd
+        # print(submit_cmd)
         return submit_cmd
 
     def submit_spark_task(self):
@@ -299,20 +334,40 @@ if __name__ == "__main__":
     # # "容器内path，没有被污染也可以不设置"
     # os.environ["PYSPARK_DRIVER_PYTHON"] = "/usr/bin/python342342342342"
 
-    if 1:  # 同步
+    if 1:  # 同步--天天
         sm = SparkManage(
             ctx={},
             # code_path='/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/debug/test_presto_s3',
             code_path='/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/debug/test_hello',
             s3_support=False, is_async=False,
+            tfrecord_support=False,
             spark_config={"task_name": "test"},
             task_params={'config': {'test': '哈哈',
                                     'a': '测试参数'}, 'config1': '测试'},
             is_log=True,  # 线上环境关闭日志
-            is_debug=True)
+            is_debug=True,
+            project_name='tt'
+            )
         sm.upload_code()
         sm.submit_spark_task()
-    else:  # 异步
+    if 0:  # 同步--talefun
+        sm = SparkManage(
+            ctx={},
+            # code_path='/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/debug/test_presto_s3',
+            code_path='/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/debug/test_hello',
+            s3_support=True, is_async=False,
+            tfrecord_support=True,
+            spark_config={"task_name": "test",
+                          "image_url": "registry-intl-vpc.us-east-1.aliyuncs.com/talefun-workspace/pyspark:1.0"},
+            task_params={'config': {'test': '哈哈',
+                                    'a': '测试参数'}, 'config1': '测试'},
+            is_log=True,  # 线上环境关闭日志
+            is_debug=True,
+            project_name='tf'
+            )
+        sm.upload_code()
+        sm.submit_spark_task()
+    if 0:  # 异步
         sm = SparkManage(
             ctx={},
             # code_path='/Users/yuanxiao/workspace/djcelery44/djcelery44/scripts/tools/debug/test_presto_s3',
